##
##  xar.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2008 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         xar
Summary:      XML Format File Archiver
URL:          http://code.google.com/p/xar/
Vendor:       K. Van Vechten, R. Braun, L. Fuller, D. Leimbach
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        EVAL
Group:        Archiver
License:      BSD
Version:      1.5.2
Release:      20080105

#   list of sources
Source0:      http://xar.googlecode.com/files/xar-%{version}.tar.gz
Patch0:       xar.patch

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 20040130
PreReq:       OpenPKG, openpkg >= 20040130
BuildPreReq:  openssl, zlib, bzip2, libxml, libiconv
PreReq:       openssl, zlib, bzip2, libxml, libiconv
AutoReq:      no
AutoReqProv:  no

%description
    The XAR project aims to provide an easily extensible archive format.
    Important design decisions include an easily extensible XML table of
    contents for random access to archived files, storing the toc at the
    beginning of the archive to allow for efficient handling of streamed
    archives, the ability to handle files of arbitrarily large sizes,
    the ability to choose independent encodings for individual files in
    the archive, the ability to store checksums for individual files in
    both compressed and uncompressed form, and the ability to query the
    table of content's rich meta-data.

%track
    prog xar = {
        version   = %{version}
        url       = http://code.google.com/p/xar/downloads/list
        regex     = xar-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --disable-autogen \
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    rm -rf $RPM_BUILD_ROOT
    %{l_make} %{l_mflags} install \
        PREFIX=$RPM_BUILD_ROOT%{l_prefix} \
        BINDIR=$RPM_BUILD_ROOT%{l_prefix}/bin \
        DATADIR=$RPM_BUILD_ROOT%{l_prefix}/share \
        LIBDIR=$RPM_BUILD_ROOT%{l_prefix}/lib \
        INCLUDEDIR=$RPM_BUILD_ROOT%{l_prefix}/include \
        MANDIR=$RPM_BUILD_ROOT%{l_prefix}/man
    rm -f $RPM_BUILD_ROOT%{l_prefix}/lib/*.a.1
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

